@@ -328,10 +328,8 @@ class EWSElement(metaclass=EWSMeta):
 
     @classmethod
     def supported_fields(cls, version):
-        """
+        """Return the fields supported by the given server version."""
 
-        :param version:
-        """
         return tuple(f for f in cls.FIELDS if not f.is_attribute and f.supports_version(version))
 
     @classmethod
@@ -430,6 +428,7 @@ class MessageHeader(EWSElement):
 
 class BaseItemId(EWSElement):
     """Base class for ItemId elements."""
+
     ID_ATTR = None
     CHANGEKEY_ATTR = None
 
@@ -1062,7 +1061,6 @@ class UserId(EWSElement):
 class BasePermission(EWSElement, metaclass=EWSMeta):
     """Base class for the Permission and CalendarPermission classes"""
 
-    ELEMENT_NAME = 'Permission'
     PERMISSION_ENUM = {Choice('None'), Choice('Owned'), Choice('All')}
 
     can_create_items = BooleanField(field_uri='CanCreateItems', default=False)
@@ -1079,22 +1077,29 @@ class BasePermission(EWSElement, metaclass=EWSMeta):
 class Permission(BasePermission):
     """MSDN: https://docs.microsoft.com/en-us/exchange/client-developer/web-service-reference/permission"""
 
-    permission_level = ChoiceField(field_uri='PermissionLevel', choices={
-        Choice('None'), Choice('Owner'), Choice('PublishingEditor'), Choice('Editor'), Choice('PublishingAuthor'),
-        Choice('Author'), Choice('NoneditingAuthor'), Choice('Reviewer'), Choice('Contributor'), Choice('Custom')
-    }, default='None')
+    ELEMENT_NAME = 'Permission'
+    LEVEL_CHOICES = (
+        'None', 'Owner', 'PublishingEditor', 'Editor', 'PublishingAuthor', 'Author', 'NoneditingAuthor', 'Reviewer',
+        'Contributor', 'Custom',
+    )
+
+    permission_level = ChoiceField(
+        field_uri='CalendarPermissionLevel', choices={Choice(c) for c in LEVEL_CHOICES}, default=LEVEL_CHOICES[0]
+    )
 
 
 class CalendarPermission(BasePermission):
     """MSDN: https://docs.microsoft.com/en-us/exchange/client-developer/web-service-reference/calendarpermission"""
 
-    ELEMENT_NAME = 'Permission'
+    ELEMENT_NAME = 'CalendarPermission'
+    LEVEL_CHOICES = (
+        'None', 'Owner', 'PublishingEditor', 'Editor', 'PublishingAuthor', 'Author', 'NoneditingAuthor', 'Reviewer',
+        'Contributor', 'FreeBusyTimeOnly', 'FreeBusyTimeAndSubjectAndLocation', 'Custom',
+    )
 
-    calendar_permission_level = ChoiceField(field_uri='CalendarPermissionLevel', choices={
-        Choice('None'), Choice('Owner'), Choice('PublishingEditor'), Choice('Editor'), Choice('PublishingAuthor'),
-        Choice('Author'), Choice('NoneditingAuthor'), Choice('Reviewer'), Choice('Contributor'),
-        Choice('FreeBusyTimeOnly'), Choice('FreeBusyTimeAndSubjectAndLocation'), Choice('Custom')
-    }, default='None')
+    calendar_permission_level = ChoiceField(
+        field_uri='CalendarPermissionLevel', choices={Choice(c) for c in LEVEL_CHOICES}, default=LEVEL_CHOICES[0]
+    )
 
 
 class PermissionSet(EWSElement):
