@@ -21,7 +21,7 @@ from ..errors import EWSWarning, TransportError, SOAPError, ErrorTimeoutExpired,
 from ..properties import FieldURI, IndexedFieldURI, ExtendedFieldURI, ExceptionFieldURI, ItemId
 from ..transport import wrap
 from ..util import chunkify, create_element, add_xml_child, get_xml_attr, to_xml, post_ratelimited, \
-    xml_to_str, set_xml_value, SOAPNS, TNS, MNS, ENS, ParseError
+    xml_to_str, set_xml_value, SOAPNS, TNS, MNS, ENS, ParseError, DummyResponse
 from ..version import API_VERSIONS, Version
 
 log = logging.getLogger(__name__)
@@ -132,6 +132,10 @@ class EWSService(metaclass=abc.ABCMeta):
         :return: Same as .call(), but returns either None or exactly one item
         """
         res = list(self.call(**kwargs))
+        # Raise any errors
+        for r in res:
+            if isinstance(r, Exception):
+                raise r
         if expect_result is None and not res:
             # Allow empty result
             return None
@@ -141,10 +145,18 @@ class EWSService(metaclass=abc.ABCMeta):
             return None
         if len(res) != 1:
             raise ValueError('Expected result length 1, but got %r' % res)
-        if isinstance(res[0], Exception):
-            raise res[0]
         return res[0]
 
+    def parse(self, xml):
+        """Used mostly for testing, when we want to parse static XML data."""
+        resp = DummyResponse(url=None, headers=None, request_headers=None, content=xml)
+        _, body = self._get_soap_parts(response=resp)
+        return self._elems_to_objs(self._get_elements_in_response(response=self._get_soap_messages(body=body)))
+
+    def _elems_to_objs(self, elems):
+        """Takes a generator of XML elements and exceptions. Returns the equivalent Python objects (or exceptions)."""
+        raise NotImplementedError()
+
     @property
     def _version_hint(self):
         # We may be here due to version guessing in Protocol.version, so we can't use the self.protocol.version property
